@@ -36,5 +36,5 @@ stackplot(basis, xlim = c(4, 0.5))
 fit_res <- fit_mrs(mrs_proc, basis)
 
 # plot the fit estimate, residual and baseline
-plot(fit_res)
+plot(fit_res, xlim = c(4, 0.5))
 
